@@ -16,16 +16,20 @@
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
 import re
+from typing import List
 
 # project
+from kiwi.command import command_call_type
 from kiwi.command import Command
 from kiwi.utils.rpm_database import RpmDataBase
 from kiwi.utils.rpm import Rpm
 from kiwi.package_manager.base import PackageManagerBase
+from kiwi.system.root_bind import RootBind
 from kiwi.path import Path
-from kiwi.exceptions import KiwiRequestError
 from kiwi.defaults import Defaults
 
+from kiwi.exceptions import KiwiRequestError
+
 
 class PackageManagerDnf(PackageManagerBase):
     """
@@ -36,21 +40,19 @@ class PackageManagerDnf(PackageManagerBase):
     :param dict command_env: dnf command environment from repository runtime
         configuration
     """
-    def post_init(self, custom_args=None):
+    def post_init(self, custom_args: List = []) -> None:
         """
         Post initialization method
 
         :param list custom_args: custom dnf arguments
         """
         self.custom_args = custom_args
-        if not custom_args:
-            self.custom_args = []
 
         runtime_config = self.repository.runtime_config()
         self.dnf_args = runtime_config['dnf_args']
         self.command_env = runtime_config['command_env']
 
-    def request_package(self, name):
+    def request_package(self, name: str) -> None:
         """
         Queue a package request
 
@@ -58,7 +60,7 @@ class PackageManagerDnf(PackageManagerBase):
         """
         self.package_requests.append(name)
 
-    def request_collection(self, name):
+    def request_collection(self, name: str) -> None:
         """
         Queue a collection request
 
@@ -66,7 +68,7 @@ class PackageManagerDnf(PackageManagerBase):
         """
         self.collection_requests.append('"' + name + '"')
 
-    def request_product(self, name):
+    def request_product(self, name: str) -> None:
         """
         Queue a product request
 
@@ -76,7 +78,7 @@ class PackageManagerDnf(PackageManagerBase):
         """
         pass
 
-    def request_package_exclusion(self, name):
+    def request_package_exclusion(self, name: str) -> None:
         """
         Queue a package exclusion(skip) request
 
@@ -84,7 +86,9 @@ class PackageManagerDnf(PackageManagerBase):
         """
         self.exclude_requests.append(name)
 
-    def process_install_requests_bootstrap(self, root_bind=None):
+    def process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> command_call_type:
         """
         Process package install requests for bootstrap phase (no chroot)
 
@@ -115,7 +119,7 @@ class PackageManagerDnf(PackageManagerBase):
             ['bash', '-c', ' '.join(bash_command)], self.command_env
         )
 
-    def process_install_requests(self):
+    def process_install_requests(self) -> command_call_type:
         """
         Process package install requests for image phase (chroot)
 
@@ -123,25 +127,26 @@ class PackageManagerDnf(PackageManagerBase):
 
         :rtype: namedtuple
         """
+        exclude_args = []
         if self.exclude_requests:
             # For DNF, excluding a package means removing it from
             # the solver operation. This is done by adding --exclude
             # to the command line. This means that if the package is
             # hard required by another package, it will break the transaction.
             for package in self.exclude_requests:
-                self.custom_args.append('--exclude=' + package)
+                exclude_args.append('--exclude=' + package)
         chroot_dnf_args = Path.move_to_root(
             self.root_dir, self.dnf_args
         )
         bash_command = [
             'chroot', self.root_dir, 'dnf'
-        ] + chroot_dnf_args + self.custom_args + [
+        ] + chroot_dnf_args + self.custom_args + exclude_args + [
             'install'
         ] + self.package_requests
         if self.collection_requests:
             bash_command += [
                 '&&', 'chroot', self.root_dir, 'dnf'
-            ] + chroot_dnf_args + self.custom_args + [
+            ] + chroot_dnf_args + self.custom_args + exclude_args + [
                 'group', 'install'
             ] + self.collection_requests
         self.cleanup_requests()
@@ -149,7 +154,7 @@ class PackageManagerDnf(PackageManagerBase):
             ['bash', '-c', ' '.join(bash_command)], self.command_env
         )
 
-    def process_delete_requests(self, force=False):
+    def process_delete_requests(self, force: bool = False) -> command_call_type:
         """
         Process package delete requests (chroot)
 
@@ -193,7 +198,7 @@ class PackageManagerDnf(PackageManagerBase):
                 self.command_env
             )
 
-    def update(self):
+    def update(self) -> command_call_type:
         """
         Process package update requests (chroot)
 
@@ -211,21 +216,23 @@ class PackageManagerDnf(PackageManagerBase):
             self.command_env
         )
 
-    def process_only_required(self):
+    def process_only_required(self) -> None:
         """
         Setup package processing only for required packages
         """
         if '--setopt=install_weak_deps=False' not in self.custom_args:
             self.custom_args.append('--setopt=install_weak_deps=False')
 
-    def process_plus_recommended(self):
+    def process_plus_recommended(self) -> None:
         """
         Setup package processing to also include recommended dependencies.
         """
         if '--setopt=install_weak_deps=False' in self.custom_args:
             self.custom_args.remove('--setopt=install_weak_deps=False')
 
-    def match_package_installed(self, package_name, dnf_output):
+    def match_package_installed(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been installed
 
@@ -234,33 +241,43 @@ class PackageManagerDnf(PackageManagerBase):
         be false positives due to sub package names starting with
         the same base package name
 
-        :param list package_list: list of all packages
-        :param str log_line: dnf status line
+        :param str package_name: package_name
+        :param str package_manager_output: dnf status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.*Installing  : ' + re.escape(package_name) + '.*', dnf_output
+        return bool(
+            re.match(
+                '.*Installing  : {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def match_package_deleted(self, package_name, dnf_output):
+    def match_package_deleted(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been deleted
 
-        :param list package_list: list of all packages
-        :param str log_line: dnf status line
+        :param str package_name: package_name
+        :param str package_manager_output: dnf status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.*Removing: ' + re.escape(package_name) + '.*', dnf_output
+        return bool(
+            re.match(
+                '.*Removing: {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def post_process_install_requests_bootstrap(self, root_bind=None):
+    def post_process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> None:
         """
         Move the rpm database to the place as it is expected by the
         rpm package installed during bootstrap phase
@@ -271,7 +288,7 @@ class PackageManagerDnf(PackageManagerBase):
         if rpmdb.has_rpm():
             rpmdb.set_database_to_image_path()
 
-    def clean_leftovers(self):
+    def clean_leftovers(self) -> None:
         """
         Cleans package manager related data not needed in the
         resulting image such as custom macros
