@@ -17,10 +17,13 @@
 #
 import re
 import logging
+from typing import List
 
 # project
+from kiwi.command import command_call_type
 from kiwi.command import Command
 from kiwi.package_manager.base import PackageManagerBase
+from kiwi.system.root_bind import RootBind
 from kiwi.exceptions import KiwiRequestError
 from kiwi.path import Path
 
@@ -29,15 +32,15 @@ log = logging.getLogger('kiwi')
 
 class PackageManagerPacman(PackageManagerBase):
     """
-    **Implements base class for installation/deletion of
-    packages and collections using pacman**
+    **Implements Installation/Deletion of packages/collections with pacman**
 
-    :param list pacman_args: pacman arguments from repository runtime
-        configuration
-    :param dict command_env: pacman command environment from repository
+    :param list pacman_args:
+        pacman arguments from repository runtime configuration
+    :param dict command_env:
+        pacman command environment from repository
         runtime configuration
     """
-    def post_init(self, custom_args=None):
+    def post_init(self, custom_args: List = None) -> None:
         """
         Post initialization method
 
@@ -53,7 +56,7 @@ class PackageManagerPacman(PackageManagerBase):
         self.pacman_args = runtime_config['pacman_args']
         self.command_env = runtime_config['command_env']
 
-    def request_package(self, name):
+    def request_package(self, name: str) -> None:
         """
         Queue a package request
 
@@ -61,7 +64,7 @@ class PackageManagerPacman(PackageManagerBase):
         """
         self.package_requests.append(name)
 
-    def request_collection(self, name):
+    def request_collection(self, name: str) -> None:
         """
         Queue a collection request
 
@@ -76,7 +79,7 @@ class PackageManagerPacman(PackageManagerBase):
         ))
         self.package_requests.append(name)
 
-    def request_product(self, name):
+    def request_product(self, name: str) -> None:
         """
         Queue a product request
 
@@ -86,7 +89,7 @@ class PackageManagerPacman(PackageManagerBase):
         """
         pass
 
-    def request_package_exclusion(self, name):
+    def request_package_exclusion(self, name: str) -> None:
         """
         Queue a package exclusion(skip) request
 
@@ -94,11 +97,13 @@ class PackageManagerPacman(PackageManagerBase):
         """
         self.exclude_requests.append(name)
 
-    def process_install_requests_bootstrap(self, root_bind=None):
+    def process_install_requests_bootstrap(
+        self, root_bind: RootBind = None
+    ) -> command_call_type:
         """
         Process package install requests for bootstrap phase (no chroot)
 
-        :param object root_binf: unused
+        :param object root_bind: unused
 
         :return: process results in command type
 
@@ -122,7 +127,7 @@ class PackageManagerPacman(PackageManagerBase):
             ['bash', '-c', ' '.join(bash_command)], self.command_env
         )
 
-    def process_install_requests(self):
+    def process_install_requests(self) -> command_call_type:
         """
         Process package install requests for image phase (chroot)
 
@@ -141,7 +146,7 @@ class PackageManagerPacman(PackageManagerBase):
             ['bash', '-c', ' '.join(bash_command)], self.command_env
         )
 
-    def process_delete_requests(self, force=False):
+    def process_delete_requests(self, force: bool = False) -> command_call_type:
         """
         Process package delete requests (chroot)
 
@@ -156,7 +161,9 @@ class PackageManagerPacman(PackageManagerBase):
         delete_items = []
         for delete_item in self.package_requests:
             try:
-                Command.run(['chroot', self.root_dir, 'pacman', '-Qi', delete_item])
+                Command.run(
+                    ['chroot', self.root_dir, 'pacman', '-Qi', delete_item]
+                )
                 delete_items.append(delete_item)
             except Exception:
                 # ignore packages which are not installed
@@ -176,7 +183,7 @@ class PackageManagerPacman(PackageManagerBase):
             self.command_env
         )
 
-    def update(self):
+    def update(self) -> command_call_type:
         """
         Process package update requests (chroot)
 
@@ -194,7 +201,7 @@ class PackageManagerPacman(PackageManagerBase):
             self.command_env
         )
 
-    def process_only_required(self):
+    def process_only_required(self) -> None:
         """
         Setup package processing only for required packages.
 
@@ -202,7 +209,7 @@ class PackageManagerPacman(PackageManagerBase):
         """
         pass
 
-    def process_plus_recommended(self):
+    def process_plus_recommended(self) -> None:
         """
         Setup package processing to also include recommended dependencies.
 
@@ -210,7 +217,9 @@ class PackageManagerPacman(PackageManagerBase):
         """
         pass
 
-    def match_package_installed(self, package_name, pacman_output):
+    def match_package_installed(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been installed
 
@@ -219,28 +228,36 @@ class PackageManagerPacman(PackageManagerBase):
         be false positives due to sub package names starting with
         the same base package name
 
-        :param list package_list: list of all packages
-        :param str log_line: dnf status line
+        :param str package_name: package_name
+        :param str package_manager_output: dnf status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.* installing ' + re.escape(package_name) + '.*', pacman_output
+        return bool(
+            re.match(
+                '.* installing {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
 
-    def match_package_deleted(self, package_name, pacman_output):
+    def match_package_deleted(
+        self, package_name: str, package_manager_output: str
+    ) -> bool:
         """
         Match expression to indicate a package has been deleted
 
-        :param list package_list: list of all packages
-        :param str log_line: pacman status line
+        :param str package_name: package_name
+        :param str package_manager_output: pacman status line
 
-        :returns: match or None if there isn't any match
+        :returns: True|False
 
-        :rtype: match object, None
+        :rtype: bool
         """
-        return re.match(
-            '.* removing ' + re.escape(package_name) + '.*', pacman_output
+        return bool(
+            re.match(
+                '.* removing {0}.*'.format(re.escape(package_name)),
+                package_manager_output
+            )
         )
