@@ -22,9 +22,7 @@ import copy
 from collections import OrderedDict
 from collections import namedtuple
 from tempfile import NamedTemporaryFile
-from typing import (
-    Any, Optional
-)
+from typing import Any
 
 # project
 import kiwi.defaults as defaults
@@ -493,7 +491,7 @@ class SystemSetup:
                 options=['-a']
             )
 
-    def export_package_list(self, target_dir: str) -> Optional[str]:
+    def export_package_list(self, target_dir: str) -> str:
         """
         Export image package list as metadata reference
         used by the open buildservice
@@ -522,9 +520,9 @@ class SystemSetup:
         elif packager == 'pacman':
             self._export_pacman_package_list(filename)
             return filename
-        return None
+        return ''
 
-    def export_package_changes(self, target_dir: str) -> Optional[str]:
+    def export_package_changes(self, target_dir: str) -> str:
         """
         Export image package changelog for comparision of
         actual changes of the installed packages
@@ -551,9 +549,9 @@ class SystemSetup:
             elif packager == 'dpkg':
                 self._export_deb_package_changes(filename)
                 return filename
-        return None
+        return ''
 
-    def export_package_verification(self, target_dir: str) -> Optional[str]:
+    def export_package_verification(self, target_dir: str) -> str:
         """
         Export package verification result as metadata reference
         used by the open buildservice
@@ -579,7 +577,7 @@ class SystemSetup:
         elif packager == 'dpkg':
             self._export_deb_package_verification(filename)
             return filename
-        return None
+        return ''
 
     def call_disk_script(self) -> None:
         """
@@ -589,6 +587,14 @@ class SystemSetup:
             defaults.POST_DISK_SYNC_SCRIPT
         )
 
+    def call_post_bootstrap_script(self) -> None:
+        """
+        Call post_bootstrap.sh script chrooted
+        """
+        self._call_script(
+            defaults.POST_BOOTSTRAP_SCRIPT
+        )
+
     def call_config_script(self) -> None:
         """
         Call config.sh script chrooted
@@ -915,6 +921,10 @@ class SystemSetup:
             'script_type', ['filepath', 'raise_if_not_exists']
         )
         custom_scripts = {
+            defaults.POST_BOOTSTRAP_SCRIPT: script_type(
+                filepath=defaults.POST_BOOTSTRAP_SCRIPT,
+                raise_if_not_exists=False
+            ),
             defaults.POST_PREPARE_SCRIPT: script_type(
                 filepath=defaults.POST_PREPARE_SCRIPT,
                 raise_if_not_exists=False
