@@ -15,9 +15,8 @@ from kiwi.exceptions import (
 
 
 class TestBootLoaderInstallGrub2:
-    @patch('platform.machine')
-    def setup(self, mock_machine):
-        mock_machine.return_value = 'x86_64'
+    def setup(self):
+        Defaults.set_platform_name('x86_64')
 
         self.firmware = mock.Mock()
         self.firmware.efi_mode = mock.Mock(
@@ -138,6 +137,10 @@ class TestBootLoaderInstallGrub2:
         self.bootloader.arch = 'arm64'
         assert self.bootloader.install_required() is False
 
+    def test_install_required_riscv64(self):
+        self.bootloader.arch = 'riscv64'
+        assert self.bootloader.install_required() is False
+
     @patch('kiwi.bootloader.install.grub2.Path.wipe')
     @patch('kiwi.bootloader.install.grub2.Path.which')
     @patch('kiwi.bootloader.install.grub2.Command.run')
@@ -316,6 +319,7 @@ class TestBootLoaderInstallGrub2:
         self, mock_glob, mock_grub_path, mock_mount_manager,
         mock_command, mock_which, mock_wipe
     ):
+        mock_which.return_value = None
         mock_glob.return_value = ['tmp_root/boot/grub2/grubenv']
         mock_grub_path.return_value = \
             self.root_mount.mountpoint + '/usr/lib/grub2/i386-pc'
@@ -348,23 +352,16 @@ class TestBootLoaderInstallGrub2:
                 '/dev/some-device'
             ])
 
-    @patch('kiwi.bootloader.install.grub2.Path.wipe')
-    @patch('kiwi.bootloader.install.grub2.Path.which')
     @patch('kiwi.bootloader.install.grub2.Command.run')
     @patch('kiwi.bootloader.install.grub2.MountManager')
-    @patch('kiwi.bootloader.install.grub2.Defaults.get_grub_path')
-    @patch('kiwi.bootloader.install.grub2.glob.glob')
     @patch('os.path.exists')
     @patch('os.access')
-    def test_install_secure_boot(
-        self, mock_access, mock_exists, mock_glob, mock_grub_path,
-        mock_mount_manager, mock_command, mock_which, mock_wipe
+    def test_secure_boot_install(
+        self, mock_access, mock_exists,
+        mock_mount_manager, mock_command
     ):
         mock_access.return_value = True
         mock_exists.return_value = True
-        mock_glob.return_value = ['tmp_root/boot/grub2/grubenv']
-        mock_grub_path.return_value = \
-            self.root_mount.mountpoint + '/usr/lib/grub2/i386-pc'
         self.firmware.efi_mode.return_value = 'uefi'
         self.boot_mount.device = self.root_mount.device
 
@@ -373,22 +370,9 @@ class TestBootLoaderInstallGrub2:
 
         mock_mount_manager.side_effect = side_effect
 
-        self.bootloader.install()
+        self.bootloader.secure_boot_install()
 
-        mock_wipe.assert_called_once_with(
-            'tmp_root/boot/grub2/grubenv'
-        )
         assert mock_command.call_args_list == [
-            call([
-                'chroot', 'tmp_root', 'grub2-install', '--skip-fs-probe',
-                '--directory', '/usr/lib/grub2/i386-pc',
-                '--boot-directory', '/boot',
-                '--target', 'i386-pc',
-                '--modules', ' '.join(
-                    Defaults.get_grub_bios_modules(multiboot=True)
-                ),
-                '/dev/some-device'
-            ]),
             call([
                 'cp', '-p', 'tmp_root/usr/sbin/grub2-install',
                 'tmp_root/usr/sbin/grub2-install.orig'
@@ -405,55 +389,40 @@ class TestBootLoaderInstallGrub2:
                 'tmp_root/usr/sbin/grub2-install'
             ])
         ]
+        self.root_mount.mount.assert_called_once_with()
+        self.volume_mount.mount.assert_called_once_with(
+            options=['subvol=@/boot/grub2']
+        )
         self.device_mount.bind_mount.assert_called_once_with()
         self.proc_mount.bind_mount.assert_called_once_with()
         self.sysfs_mount.bind_mount.assert_called_once_with()
         self.efi_mount.mount.assert_called_once_with()
 
-    @patch('kiwi.bootloader.install.grub2.Path.wipe')
     @patch('kiwi.bootloader.install.grub2.Path.which')
-    @patch('kiwi.bootloader.install.grub2.Command.run')
     @patch('kiwi.bootloader.install.grub2.MountManager')
-    @patch('kiwi.bootloader.install.grub2.Defaults.get_grub_path')
-    @patch('kiwi.bootloader.install.grub2.glob.glob')
-    @patch('os.path.exists')
-    def test_install_secure_boot_no_shim_install(
-        self, mock_exists, mock_glob, mock_grub_path, mock_mount_manager,
-        mock_command, mock_which, mock_wipe
+    def test_secure_boot_install_no_shim_install(
+        self, mock_mount_manager, mock_which
     ):
         mock_which.return_value = None
-        mock_exists.return_value = True
-        mock_glob.return_value = ['tmp_root/boot/grub2/grubenv']
-        mock_grub_path.return_value = \
-            self.root_mount.mountpoint + '/usr/lib/grub2/i386-pc'
         self.firmware.efi_mode.return_value = 'uefi'
-        self.boot_mount.device = self.root_mount.device
 
         def side_effect(device, mountpoint=None):
             return self.mount_managers.pop()
 
         mock_mount_manager.side_effect = side_effect
 
-        self.bootloader.install()
-
-        mock_wipe.assert_called_once_with(
-            'tmp_root/boot/grub2/grubenv'
+        self.bootloader.secure_boot_install()
+        self.root_mount.mount.assert_called_once_with()
+        self.volume_mount.mount.assert_called_once_with(
+            options=['subvol=@/boot/grub2']
         )
-        assert mock_command.call_args_list == [
-            call([
-                'chroot', 'tmp_root', 'grub2-install', '--skip-fs-probe',
-                '--directory', '/usr/lib/grub2/i386-pc',
-                '--boot-directory', '/boot',
-                '--target', 'i386-pc',
-                '--modules', ' '.join(
-                    Defaults.get_grub_bios_modules(multiboot=True)
-                ),
-                '/dev/some-device'
-            ])
-        ]
         self.device_mount.bind_mount.assert_called_once_with()
         self.proc_mount.bind_mount.assert_called_once_with()
         self.sysfs_mount.bind_mount.assert_called_once_with()
+        self.efi_mount.mount.assert_called_once_with()
+        mock_which.assert_called_once_with(
+            filename='shim-install', root_dir='tmp_root'
+        )
 
     @patch('kiwi.bootloader.install.grub2.Command.run')
     @patch('kiwi.bootloader.install.grub2.MountManager')
