@@ -2,12 +2,13 @@ import logging
 from mock import patch
 
 import sys
-import mock
+from mock import MagicMock
 from pytest import fixture
 
 from .test_helper import argv_kiwi_tests
 
 from kiwi.defaults import Defaults
+from kiwi.defaults import grub_loader_type
 
 
 class TestDefaults:
@@ -31,7 +32,7 @@ class TestDefaults:
         assert self.defaults.get('kiwi_revision')
 
     def test_to_profile(self):
-        profile = mock.MagicMock()
+        profile = MagicMock()
         self.defaults.to_profile(profile)
         profile.add.assert_any_call('kiwi_align', 1048576)
         profile.add.assert_any_call('kiwi_startsector', 2048)
@@ -110,3 +111,39 @@ class TestDefaults:
             assert Defaults.get_exclude_list_from_custom_exclude_files(
                 '../data/root-dir'
             ) == []
+
+    @patch('glob.iglob')
+    def test_get_signed_grub_loader(self, mock_iglob):
+        def iglob_no_matches(pattern):
+            return []
+
+        def iglob_simple_match(pattern):
+            if '/boot/efi/EFI/*/grub*.efi' in pattern:
+                return ['root_path/boot/efi/EFI/BOOT/grub.efi']
+            else:
+                return []
+
+        def iglob_custom_binary_match(pattern):
+            if '/usr/lib/grub/x86_64-efi-signed/grubx64.efi.signed' in pattern:
+                return [
+                    'root_path'
+                    '/usr/lib/grub/x86_64-efi-signed/grubx64.efi.signed'
+                ]
+            else:
+                return []
+
+        mock_iglob.side_effect = iglob_no_matches
+        assert Defaults.get_signed_grub_loader('root_path') is None
+
+        mock_iglob.side_effect = iglob_simple_match
+        assert Defaults.get_signed_grub_loader('root_path') == grub_loader_type(
+            filename='root_path/boot/efi/EFI/BOOT/grub.efi',
+            binaryname='grub.efi'
+        )
+
+        mock_iglob.side_effect = iglob_custom_binary_match
+        assert Defaults.get_signed_grub_loader('root_path') == grub_loader_type(
+            filename='root_path'
+            '/usr/lib/grub/x86_64-efi-signed/grubx64.efi.signed',
+            binaryname='grubx64.efi'
+        )
