@@ -1,15 +1,15 @@
 from mock import patch
 from pytest import raises
 
+from kiwi.defaults import Defaults
 from kiwi.iso_tools.xorriso import IsoToolsXorrIso
 
 from kiwi.exceptions import KiwiIsoToolError
 
 
 class TestIsoToolsXorrIso:
-    @patch('platform.machine')
-    def setup(self, mock_machine):
-        mock_machine.return_value = 'x86_64'
+    def setup(self):
+        Defaults.set_platform_name('x86_64')
         self.iso_tool = IsoToolsXorrIso('source-dir')
 
     @patch('kiwi.iso_tools.xorriso.Path.which')
