@@ -14,10 +14,16 @@ class TestPackageManagerMicroDnf:
 
         repository.runtime_config = mock.Mock(
             return_value={
-                'dnf_args': ['-c', '/root-dir/dnf.conf', '-y'],
+                'dnf_args': ['--config', '/root-dir/dnf.conf', '-y'],
                 'command_env': ['env']
             }
         )
+        repository.shared_dnf_dir = {
+            'reposd-dir': 'repos',
+            'cache-dir': 'cache',
+            'pluginconf-dir': 'pluginconf',
+            'vars-dir': 'vars'
+        }
         self.manager = PackageManagerMicroDnf(repository)
 
     def test_request_package(self):
@@ -42,14 +48,15 @@ class TestPackageManagerMicroDnf:
         self.manager.request_package('vim')
         self.manager.request_collection('collection')
         self.manager.process_install_requests_bootstrap()
-        mock_run.assert_called_once_with(
-            ['microdnf', '-c', '/root-dir/dnf.conf', '-y', 'makecache']
-        )
         mock_call.assert_called_once_with(
             [
                 'bash', '-c',
-                'microdnf -c /root-dir/dnf.conf -y '
-                '--installroot /root-dir install vim'
+                'microdnf --refresh --config /root-dir/dnf.conf -y '
+                '--installroot /root-dir --releasever=0 --noplugins '
+                '--setopt=cachedir=cache '
+                '--setopt=reposdir=repos '
+                '--setopt=varsdir=vars '
+                'install vim'
             ], ['env']
         )
 
@@ -62,7 +69,7 @@ class TestPackageManagerMicroDnf:
         mock_call.assert_called_once_with(
             [
                 'bash', '-c',
-                'chroot /root-dir microdnf -c /dnf.conf -y '
+                'chroot /root-dir microdnf --config /dnf.conf -y '
                 '--exclude=skipme install vim'
             ], ['env']
         )
@@ -90,7 +97,7 @@ class TestPackageManagerMicroDnf:
         mock_call.assert_called_once_with(
             [
                 'chroot', '/root-dir', 'microdnf',
-                '-c', '/dnf.conf', '-y', 'remove', 'vim'
+                '--config', '/dnf.conf', '-y', 'remove', 'vim'
             ],
             ['env']
         )
@@ -114,20 +121,20 @@ class TestPackageManagerMicroDnf:
         mock_call.assert_called_once_with(
             [
                 'chroot', '/root-dir', 'microdnf',
-                '-c', '/dnf.conf', '-y', 'upgrade'
+                '--config', '/dnf.conf', '-y', 'upgrade'
             ], ['env']
         )
 
     def test_process_only_required(self):
         self.manager.process_only_required()
-        assert self.manager.custom_args == ['--setopt=install_weak_deps=False']
+        assert self.manager.custom_args == ['--setopt=install_weak_deps=0']
 
     def test_process_plus_recommended(self):
         self.manager.process_only_required()
-        assert self.manager.custom_args == ['--setopt=install_weak_deps=False']
+        assert self.manager.custom_args == ['--setopt=install_weak_deps=0']
         self.manager.process_plus_recommended()
         assert \
-            '--setopt=install_weak_deps=False' not in self.manager.custom_args
+            '--setopt=install_weak_deps=0' not in self.manager.custom_args
 
     def test_match_package_installed(self):
         assert self.manager.match_package_installed('foo', 'Installing  : foo')
