@@ -16,6 +16,7 @@ from kiwi.exceptions import (
     KiwiPackagesDeletePhaseFailed
 )
 
+from kiwi.defaults import Defaults
 from kiwi.system.prepare import SystemPrepare
 from kiwi.xml_description import XMLDescription
 from kiwi.xml_state import XMLState
@@ -30,6 +31,7 @@ class TestSystemPrepare:
     @patch('kiwi.system.prepare.RootBind')
     @patch('kiwi.logger.Logger.get_logfile')
     def setup(self, mock_get_logfile, mock_root_bind, mock_root_init):
+        Defaults.set_platform_name('x86_64')
         mock_get_logfile.return_value = None
         description = XMLDescription(
             description='../data/example_config.xml',
@@ -195,13 +197,15 @@ class TestSystemPrepare:
 
         self.system.setup_repositories(
             clear_cache=True,
-            signing_keys=['key-file-a.asc', 'key-file-b.asc']
+            signing_keys=['key-file-a.asc', 'key-file-b.asc'],
+            target_arch='x86_64'
         )
 
         mock_repo.assert_called_once_with(
             self.system.root_bind, 'package-manager-name', [
                 'check_signatures', 'exclude_docs',
-                '_install_langs%POSIX:C:C.UTF-8:en_US:de_DE'
+                '_install_langs%POSIX:C:C.UTF-8:en_US:de_DE',
+                '_target_arch%x86_64'
             ]
         )
         # mock local repos will be translated and bind mounted
