@@ -141,7 +141,7 @@ class TestSystemPrepareTask:
             check_architecture_supports_iso_firmware_setup.\
             assert_called_once_with()
         self.system_prepare.setup_repositories.assert_called_once_with(
-            True, None
+            True, None, None
         )
         self.system_prepare.install_bootstrap.assert_called_once_with(
             self.manager, []
@@ -177,7 +177,7 @@ class TestSystemPrepareTask:
         self.task.command_args['--add-package'] = ['vim']
         self.task.process()
         self.system_prepare.setup_repositories.assert_called_once_with(
-            False, None
+            False, None, None
         )
         self.system_prepare.install_packages.assert_called_once_with(
             self.manager, ['vim']
@@ -188,7 +188,7 @@ class TestSystemPrepareTask:
         self.task.command_args['--delete-package'] = ['vim']
         self.task.process()
         self.system_prepare.setup_repositories.assert_called_once_with(
-            False, None
+            False, None, None
         )
         self.system_prepare.delete_packages.assert_called_once_with(
             self.manager, ['vim']
